package VMOMI::HostDisconnectedEventReasonCode;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
